@@ -33,16 +33,18 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.aws_kms
-import aws_cdk.aws_lambda
-import aws_cdk.aws_s3
-import aws_cdk.aws_ses
-import aws_cdk.aws_sns
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_e491a92b
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_55f001a5
+import aws_cdk.aws_ses as _aws_cdk_aws_ses_b8f9c394
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_889c7272
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class AddHeader(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-ses-actions.AddHeader",
@@ -98,13 +100,16 @@ class AddHeader(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param _rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__83e62c47a3073f2fa057acf62f9842bd0161c1e30751c3579d931081d0010241)
+            check_type(argname="argument _rule", value=_rule, expected_type=type_hints["_rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
 
 @jsii.data_type(
@@ -155,7 +160,11 @@ class AddHeaderProps:
                 ]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cf7eed0eabb35a3d9510a514abe92497021b023b56ba9682b716fda62d494d90)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "value": value,
         }
@@ -195,7 +204,7 @@ class AddHeaderProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce"):
     '''Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
@@ -225,7 +234,7 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         *,
         sender: builtins.str,
         template: "BounceTemplate",
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
@@ -239,13 +248,16 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param _rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__32785a0b7d9413fe20b4aafc8f06f718ccc235c60f88c5a82ed16f3bcddb38ca)
+            check_type(argname="argument _rule", value=_rule, expected_type=type_hints["_rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
 
 @jsii.data_type(
@@ -259,7 +271,7 @@ class BounceProps:
         *,
         sender: builtins.str,
         template: "BounceTemplate",
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''Construction properties for a bounce action.
 
@@ -287,7 +299,12 @@ class BounceProps:
                 topic=topic
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0a9d72774b8be6e2d2b1f96682e3960356d65ab6320051251a3dfb9b874c5331)
+            check_type(argname="argument sender", value=sender, expected_type=type_hints["sender"])
+            check_type(argname="argument template", value=template, expected_type=type_hints["template"])
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "sender": sender,
             "template": template,
         }
@@ -313,13 +330,13 @@ class BounceProps:
         return typing.cast("BounceTemplate", result)
 
     @builtins.property
-    def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
+    def topic(self) -> typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic]:
         '''The SNS topic to notify when the bounce action is taken.
 
         :default: no notification
         '''
         result = self._values.get("topic")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -368,32 +385,32 @@ class BounceTemplate(
 
         jsii.create(self.__class__, self, [props])
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
     def MAILBOX_DOES_NOT_EXIST(cls) -> "BounceTemplate":
         return typing.cast("BounceTemplate", jsii.sget(cls, "MAILBOX_DOES_NOT_EXIST"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="MAILBOX_FULL")
     def MAILBOX_FULL(cls) -> "BounceTemplate":
         return typing.cast("BounceTemplate", jsii.sget(cls, "MAILBOX_FULL"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="MESSAGE_CONTENT_REJECTED")
     def MESSAGE_CONTENT_REJECTED(cls) -> "BounceTemplate":
         return typing.cast("BounceTemplate", jsii.sget(cls, "MESSAGE_CONTENT_REJECTED"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="MESSAGE_TOO_LARGE")
     def MESSAGE_TOO_LARGE(cls) -> "BounceTemplate":
         return typing.cast("BounceTemplate", jsii.sget(cls, "MESSAGE_TOO_LARGE"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="TEMPORARY_FAILURE")
     def TEMPORARY_FAILURE(cls) -> "BounceTemplate":
         return typing.cast("BounceTemplate", jsii.sget(cls, "TEMPORARY_FAILURE"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="props")
     def props(self) -> "BounceTemplateProps":
         return typing.cast("BounceTemplateProps", jsii.get(self, "props"))
@@ -438,7 +455,12 @@ class BounceTemplateProps:
                 status_code="statusCode"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__de96ec77596b08d03d0643fe3d841a0a40bb3f75479fb08bc5fd12b962a04306)
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
+            check_type(argname="argument smtp_reply_code", value=smtp_reply_code, expected_type=type_hints["smtp_reply_code"])
+            check_type(argname="argument status_code", value=status_code, expected_type=type_hints["status_code"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "message": message,
             "smtp_reply_code": smtp_reply_code,
         }
@@ -493,7 +515,7 @@ class EmailEncoding(enum.Enum):
     '''UTF-8.'''
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda"):
     '''Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
@@ -522,9 +544,9 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
     def __init__(
         self,
         *,
-        function: aws_cdk.aws_lambda.IFunction,
+        function: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         invocation_type: typing.Optional["LambdaInvocationType"] = None,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''
         :param function: The Lambda function to invoke.
@@ -540,13 +562,16 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9ee0690847d1cf346edface8531759c56aeeab60ceddd1bfc5742381cc50dacf)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.LambdaInvocationType")
@@ -577,9 +602,9 @@ class LambdaProps:
     def __init__(
         self,
         *,
-        function: aws_cdk.aws_lambda.IFunction,
+        function: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         invocation_type: typing.Optional[LambdaInvocationType] = None,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''Construction properties for a Lambda action.
 
@@ -608,7 +633,12 @@ class LambdaProps:
                 topic=topic
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__da29c068d9e0c6064dedc8cedacf82ba8ec7da99207a04293e46bc64894b6b1f)
+            check_type(argname="argument function", value=function, expected_type=type_hints["function"])
+            check_type(argname="argument invocation_type", value=invocation_type, expected_type=type_hints["invocation_type"])
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "function": function,
         }
         if invocation_type is not None:
@@ -617,11 +647,11 @@ class LambdaProps:
             self._values["topic"] = topic
 
     @builtins.property
-    def function(self) -> aws_cdk.aws_lambda.IFunction:
+    def function(self) -> _aws_cdk_aws_lambda_5443dbc3.IFunction:
         '''The Lambda function to invoke.'''
         result = self._values.get("function")
         assert result is not None, "Required property 'function' is missing"
-        return typing.cast(aws_cdk.aws_lambda.IFunction, result)
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.IFunction, result)
 
     @builtins.property
     def invocation_type(self) -> typing.Optional[LambdaInvocationType]:
@@ -633,13 +663,13 @@ class LambdaProps:
         return typing.cast(typing.Optional[LambdaInvocationType], result)
 
     @builtins.property
-    def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
+    def topic(self) -> typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic]:
         '''The SNS topic to notify when the Lambda action is taken.
 
         :default: no notification
         '''
         result = self._values.get("topic")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -653,7 +683,7 @@ class LambdaProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
     '''Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
 
@@ -697,10 +727,10 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
     def __init__(
         self,
         *,
-        bucket: aws_cdk.aws_s3.IBucket,
-        kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+        kms_key: typing.Optional[_aws_cdk_aws_kms_e491a92b.IKey] = None,
         object_key_prefix: typing.Optional[builtins.str] = None,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''
         :param bucket: The S3 bucket that incoming email will be saved to.
@@ -720,13 +750,16 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b5997337e7d9c333c826453698a6f90415823277cfd5dc3dc1c7b8dd11c69c53)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
 @jsii.data_type(
@@ -743,10 +776,10 @@ class S3Props:
     def __init__(
         self,
         *,
-        bucket: aws_cdk.aws_s3.IBucket,
-        kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+        kms_key: typing.Optional[_aws_cdk_aws_kms_e491a92b.IKey] = None,
         object_key_prefix: typing.Optional[builtins.str] = None,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''Construction properties for a S3 action.
 
@@ -791,7 +824,13 @@ class S3Props:
                 ]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__82d01ca4c64e4cdec9c2038b9ce262c3eb9561c3600503d6a8960a4b7b7b6886)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument kms_key", value=kms_key, expected_type=type_hints["kms_key"])
+            check_type(argname="argument object_key_prefix", value=object_key_prefix, expected_type=type_hints["object_key_prefix"])
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bucket": bucket,
         }
         if kms_key is not None:
@@ -802,20 +841,20 @@ class S3Props:
             self._values["topic"] = topic
 
     @builtins.property
-    def bucket(self) -> aws_cdk.aws_s3.IBucket:
+    def bucket(self) -> _aws_cdk_aws_s3_55f001a5.IBucket:
         '''The S3 bucket that incoming email will be saved to.'''
         result = self._values.get("bucket")
         assert result is not None, "Required property 'bucket' is missing"
-        return typing.cast(aws_cdk.aws_s3.IBucket, result)
+        return typing.cast(_aws_cdk_aws_s3_55f001a5.IBucket, result)
 
     @builtins.property
-    def kms_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
+    def kms_key(self) -> typing.Optional[_aws_cdk_aws_kms_e491a92b.IKey]:
         '''The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
 
         :default: no encryption
         '''
         result = self._values.get("kms_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_e491a92b.IKey], result)
 
     @builtins.property
     def object_key_prefix(self) -> typing.Optional[builtins.str]:
@@ -827,13 +866,13 @@ class S3Props:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
+    def topic(self) -> typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic]:
         '''The SNS topic to notify when the S3 action is taken.
 
         :default: no notification
         '''
         result = self._values.get("topic")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -847,7 +886,7 @@ class S3Props:
         )
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
     '''Publishes the email content within a notification to Amazon SNS.
 
@@ -891,7 +930,7 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
     def __init__(
         self,
         *,
-        topic: aws_cdk.aws_sns.ITopic,
+        topic: _aws_cdk_aws_sns_889c7272.ITopic,
         encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
         '''
@@ -905,13 +944,16 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param _rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__594d4dbd36338a6129440938bba6a77e4813538082203c997ab5dae502e43102)
+            check_type(argname="argument _rule", value=_rule, expected_type=type_hints["_rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
 
 @jsii.data_type(
@@ -923,7 +965,7 @@ class SnsProps:
     def __init__(
         self,
         *,
-        topic: aws_cdk.aws_sns.ITopic,
+        topic: _aws_cdk_aws_sns_889c7272.ITopic,
         encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
         '''Construction properties for a SNS action.
@@ -967,18 +1009,22 @@ class SnsProps:
                 ]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2030df3cfc0117247d81de06d9c7d2a1d88d95b646559148a708a95cffa74803)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
+            check_type(argname="argument encoding", value=encoding, expected_type=type_hints["encoding"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "topic": topic,
         }
         if encoding is not None:
             self._values["encoding"] = encoding
 
     @builtins.property
-    def topic(self) -> aws_cdk.aws_sns.ITopic:
+    def topic(self) -> _aws_cdk_aws_sns_889c7272.ITopic:
         '''The SNS topic to notify.'''
         result = self._values.get("topic")
         assert result is not None, "Required property 'topic' is missing"
-        return typing.cast(aws_cdk.aws_sns.ITopic, result)
+        return typing.cast(_aws_cdk_aws_sns_889c7272.ITopic, result)
 
     @builtins.property
     def encoding(self) -> typing.Optional[EmailEncoding]:
@@ -1001,7 +1047,7 @@ class SnsProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
+@jsii.implements(_aws_cdk_aws_ses_b8f9c394.IReceiptRuleAction)
 class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
     '''Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
@@ -1024,7 +1070,7 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
     def __init__(
         self,
         *,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''
         :param topic: The SNS topic to notify when the stop action is taken.
@@ -1036,13 +1082,16 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _rule: aws_cdk.aws_ses.IReceiptRule,
-    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+        _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+    ) -> _aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig:
         '''Returns the receipt rule action specification.
 
         :param _rule: -
         '''
-        return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8d704a6b39ca84228a72395f25eb274c7cfbbbf1f6be0a2d0c3a4af09da85c28)
+            check_type(argname="argument _rule", value=_rule, expected_type=type_hints["_rule"])
+        return typing.cast(_aws_cdk_aws_ses_b8f9c394.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
 
 @jsii.data_type(
@@ -1054,7 +1103,7 @@ class StopProps:
     def __init__(
         self,
         *,
-        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+        topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
     ) -> None:
         '''Construction properties for a stop action.
 
@@ -1075,15 +1124,18 @@ class StopProps:
                 topic=topic
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__262765d74e99561035e4bf24b371987b8ecaffabee8b65ae2556a77af49e5d18)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if topic is not None:
             self._values["topic"] = topic
 
     @builtins.property
-    def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
+    def topic(self) -> typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic]:
         '''The SNS topic to notify when the stop action is taken.'''
         result = self._values.get("topic")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1117,3 +1169,99 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__83e62c47a3073f2fa057acf62f9842bd0161c1e30751c3579d931081d0010241(
+    _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cf7eed0eabb35a3d9510a514abe92497021b023b56ba9682b716fda62d494d90(
+    *,
+    name: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__32785a0b7d9413fe20b4aafc8f06f718ccc235c60f88c5a82ed16f3bcddb38ca(
+    _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a9d72774b8be6e2d2b1f96682e3960356d65ab6320051251a3dfb9b874c5331(
+    *,
+    sender: builtins.str,
+    template: BounceTemplate,
+    topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__de96ec77596b08d03d0643fe3d841a0a40bb3f75479fb08bc5fd12b962a04306(
+    *,
+    message: builtins.str,
+    smtp_reply_code: builtins.str,
+    status_code: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9ee0690847d1cf346edface8531759c56aeeab60ceddd1bfc5742381cc50dacf(
+    rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__da29c068d9e0c6064dedc8cedacf82ba8ec7da99207a04293e46bc64894b6b1f(
+    *,
+    function: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    invocation_type: typing.Optional[LambdaInvocationType] = None,
+    topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b5997337e7d9c333c826453698a6f90415823277cfd5dc3dc1c7b8dd11c69c53(
+    rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__82d01ca4c64e4cdec9c2038b9ce262c3eb9561c3600503d6a8960a4b7b7b6886(
+    *,
+    bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+    kms_key: typing.Optional[_aws_cdk_aws_kms_e491a92b.IKey] = None,
+    object_key_prefix: typing.Optional[builtins.str] = None,
+    topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__594d4dbd36338a6129440938bba6a77e4813538082203c997ab5dae502e43102(
+    _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2030df3cfc0117247d81de06d9c7d2a1d88d95b646559148a708a95cffa74803(
+    *,
+    topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    encoding: typing.Optional[EmailEncoding] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8d704a6b39ca84228a72395f25eb274c7cfbbbf1f6be0a2d0c3a4af09da85c28(
+    _rule: _aws_cdk_aws_ses_b8f9c394.IReceiptRule,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__262765d74e99561035e4bf24b371987b8ecaffabee8b65ae2556a77af49e5d18(
+    *,
+    topic: typing.Optional[_aws_cdk_aws_sns_889c7272.ITopic] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
